Bpc

Struct Bpc 

pub struct Bpc {
    pub revision: u32,
    pub power_threshold_support: PowerThresholdSupport,
    pub max_instantaneous_peak_power_threshold: u32,
    pub max_sustainable_peak_power_threshold: u32,
}
BPC: Battery Power Characteristics.

Represents static values returned by the platform firmware that describe the battery’s power delivery capabilities and threshold support.

Fields

revision: u32

Revision of the BPC structure.

For this version of the specification, the revision must be set to 1.

power_threshold_support: PowerThresholdSupport

Power threshold support capability of the platform firmware.

This is a bitfield indicating which types of power thresholds are supported.

max_instantaneous_peak_power_threshold: u32

Maximum supported threshold for instantaneous peak power (in mW or mA).

This value defines the upper bound for the instantaneous peak power threshold that can be set using _BPT.

max_sustainable_peak_power_threshold: u32

Maximum supported threshold for sustainable peak power (in mW or mA).

This value defines the upper bound for the sustainable peak power threshold that can be set using _BPT.