ErrorCode

Enum ErrorCode 

#[repr(u8)]
pub enum ErrorCode { Ok = 0, Busy = 1, ReservedCmd = 2, UnsupportedCmd = 3, AccessDenied = 4, UnderOverFlow = 5, BadSize = 6, UnknownError = 7, }
Error codes that must be supported by the Smart Battery.

Variants



Ok = 0

The Smart Battery processed the function code without detecting any errors.



Busy = 1

The Smart Battery is unable to process the function code at this time.



ReservedCmd = 2

The Smart Battery detected an attempt to read or write to a function code reserved by this version of the specification. The Smart Battery detected an attempt to access an unsupported optional manufacturer function code.



UnsupportedCmd = 3

The Smart Battery does not support this function code which is defined in this version of the specification.



AccessDenied = 4

The Smart Battery detected an attempt to write to a read only function code.



UnderOverFlow = 5

The Smart Battery detected a data overflow or under flow.



BadSize = 6

The Smart Battery detected an attempt to write to a function code with an incorrect size data block.



UnknownError = 7

The Smart Battery detected an unidentifiable error.