Struct Bpc
Source pub struct Bpc {
pub revision: u32,
pub power_threshold_support: PowerThresholdSupport,
pub max_instantaneous_peak_power_threshold: u32,
pub max_sustainable_peak_power_threshold: u32,
}
BPC: Battery Power Characteristics.
Represents static values returned by the platform firmware that describe
the battery’s power delivery capabilities and threshold support.
Revision of the BPC structure.
For this version of the specification, the revision must be set to 1.
Power threshold support capability of the platform firmware.
This is a bitfield indicating which types of power thresholds are supported.
Maximum supported threshold for instantaneous peak power (in mW or mA).
This value defines the upper bound for the instantaneous peak power threshold
that can be set using _BPT.
Maximum supported threshold for sustainable peak power (in mW or mA).
This value defines the upper bound for the sustainable peak power threshold
that can be set using _BPT.
Performs copy-assignment from
source.
Read more
Returns the “default value” for a type.
Read more
Reads a copy of
Self from the given
source.
Read more
Reads a copy of
Self from the prefix of the given
source.
Read more
Reads a copy of
Self from the suffix of the given
source.
Read more
Creates an instance of
Self from zeroed bytes.
Read more
Gets the bytes of this value mutably.
Read more
Writes a copy of
self to the prefix of
dst.
Read more
Writes a copy of
self to the suffix of
dst.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Attempts to read the given
source as a
Self.
Read more
Attempts to read a
Self from the prefix of the given
source.
Read more
Attempts to read a
Self from the suffix of the given
source.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.